OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeri",
    "Error loading slideshow template" : "Ralat memuatkan templat persembahan slaid",
    "Next" : "Seterus",
    "Play" : "Main",
    "Pause" : "Jeda",
    "Previous" : "Sebelum",
    "Close" : "Tutup",
    "Download" : "Muat turun",
    "Delete" : "Padam",
    "Share" : "Kongsi",
    "Upload" : "Muat naik",
    "Error" : "Ralat",
    "Password" : "Kata laluan",
    "Send" : "Hantar",
    "group" : "kumpulan",
    "can share" : "boleh berkongsi",
    "can edit" : "boleh mengubah",
    "Warning" : "Amaran",
    "Cancel upload" : "Batal muat naik"
},
"nplurals=1; plural=0;");
